@@ -165,7 +165,7 @@ struct custom_button {
 
 std::string shortcut_to_text(guint key, guint state);
 const gchar *shortcut_type_text(int type, bool return_null = false);
-void update_accels();
+void update_accels(int type = -1);
 
 DECLARE_BUILTIN_FUNCTION(AnswerFunction, 0)
 DECLARE_BUILTIN_FUNCTION(ExpressionFunction, 0)
@@ -413,7 +413,7 @@ void on_menu_item_quit_activate(GtkMenuItem *w, gpointer user_data);
 void on_colorbutton_status_error_color_color_set(GtkColorButton *w, gpointer user_data);
 void on_colorbutton_status_warning_color_color_set(GtkColorButton *w, gpointer user_data);
 void on_preferences_checkbutton_persistent_keypad_toggled(GtkToggleButton *w, gpointer user_data);
-void on_preferences_checkbutton_copy_separator_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_checkbutton_copy_ascii_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_lower_case_numbers_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_e_notation_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_lower_case_e_toggled(GtkToggleButton *w, gpointer user_data);
@@ -602,6 +602,7 @@ void on_popup_menu_item_exact_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_assume_nonzero_denominators_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_abort_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_clear_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_clear_history_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_normal_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_engineering_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_scientific_activate(GtkMenuItem *w, gpointer user_data);
@@ -683,6 +684,7 @@ void on_menu_item_ic_simple(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_save_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_save_image_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_copy_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_copy_ascii_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_precision_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_decimals_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_plot_functions_activate(GtkMenuItem *w, gpointer user_data);
