@@ -65,6 +65,7 @@ extern bool minimal_mode;
 extern gint hidden_x, hidden_y, hidden_monitor;
 extern bool hidden_monitor_primary;
 bool check_version = false;
+extern int version_numbers[3];
 extern int unformatted_history;
 string custom_title;
 
@@ -150,6 +151,10 @@ static gboolean on_sigterm_received(gpointer) {
 
 void create_application(GtkApplication *app) {
 
+#ifdef _WIN32
+	AllowSetForegroundWindow(0);
+#endif
+
 #if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 14
 	gtk_icon_theme_add_resource_path(gtk_icon_theme_get_default(), "/qalculate-gtk/icons");
 #endif
@@ -202,23 +207,33 @@ void create_application(GtkApplication *app) {
 	while(gtk_events_pending()) gtk_main_iteration();
 	test_border();
 
-	showing_first_time_message = first_time;
+	showing_first_time_message = first_time || version_numbers[0] != 4 || version_numbers[1] != 1;
 
-	if(calc_arg.empty() && first_time && file_arg.empty()) {
-		PangoLayout *layout = gtk_widget_create_pango_layout(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview")), NULL);
-		GdkRGBA rgba;
+	if(calc_arg.empty() && showing_first_time_message && file_arg.empty()) {
 #if GDK_MAJOR_VERSION > 3 || GDK_MINOR_VERSION >= 22
 		GdkDrawingContext *gdc = gdk_window_begin_draw_frame(gtk_widget_get_window(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview"))), cairo_region_create());
 		cairo_t *cr = gdk_drawing_context_get_cairo_context(gdc);
 #else
 		cairo_t *cr = gdk_cairo_create(gtk_widget_get_window(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview"))));
 #endif
+		/*PangoLayout *layout = gtk_widget_create_pango_layout(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview")), NULL);
+		GdkRGBA rgba;
 		pango_layout_set_markup(layout, (string("<span size=\"smaller\">") + string(_("Type a mathematical expression above, e.g. \"5 + 2 / 3\",\nand press the enter key.")) + "</span>").c_str(), -1);
 		gtk_style_context_get_color(gtk_widget_get_style_context(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview"))), gtk_widget_get_state_flags(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview"))), &rgba);
 		cairo_move_to(cr, 6, 6);
 		gdk_cairo_set_source_rgba(cr, &rgba);
 		pango_cairo_show_layout(cr, layout);
-		g_object_unref(layout);
+		g_object_unref(layout);*/
+		gint h = gtk_widget_get_allocated_height(GTK_WIDGET(gtk_builder_get_object(main_builder, "scrolled_result")));
+		gint w = gtk_widget_get_allocated_width(GTK_WIDGET(gtk_builder_get_object(main_builder, "scrolled_result")));
+		gint uah_h = 16, uah_w = 24;
+		if(h >= 48) {uah_h = 32; uah_w = 48;}
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_resource_at_scale("/qalculate-gtk/flags/UAH.png", uah_w, uah_h, TRUE, NULL);
+		cairo_surface_t *s = gdk_cairo_surface_create_from_pixbuf(pixbuf, 1, NULL);
+		cairo_set_source_surface(cr, s, (w - uah_w) / 2, (h - uah_h) / 2);
+		cairo_paint(cr);
+		g_object_unref(pixbuf);
+		cairo_surface_destroy(s);
 #if GDK_MAJOR_VERSION > 3 || GDK_MINOR_VERSION >= 22
 		gdk_window_end_draw_frame(gtk_widget_get_window(GTK_WIDGET(gtk_builder_get_object(main_builder, "resultview"))), gdc);
 #else
@@ -320,7 +335,7 @@ void create_application(GtkApplication *app) {
 	if(!calc_arg.empty()) {
 		gtk_text_buffer_set_text(GTK_TEXT_BUFFER(gtk_builder_get_object(main_builder, "expressionbuffer")), calc_arg.c_str(), -1);
 		execute_expression();
-	} else if(!first_time && !minimal_mode && !file_arg.empty()) {
+	} else if(!showing_first_time_message && !minimal_mode && !file_arg.empty()) {
 		int base = printops.base;
 		printops.base = 10;
 		setResult(NULL, false, false, false);
@@ -389,8 +404,6 @@ static void qalculate_activate(GtkApplication *app) {
 			hidden_x = -1;
 		}
 #ifdef _WIN32
-		gtk_window_iconify(GTK_WINDOW(list->data));
-		while(gtk_events_pending()) gtk_main_iteration();
 		gtk_window_present_with_time(GTK_WINDOW(list->data), GDK_CURRENT_TIME);
 #endif
 		if(expressiontext) gtk_widget_grab_focus(expressiontext);
@@ -467,6 +480,9 @@ static gint qalculate_handle_local_options(GtkApplication *app, GVariantDict *op
 	}
 	g_free(gstr_file);
 	if(allow_multiple_instances > 0) g_application_set_flags(G_APPLICATION(app), G_APPLICATION_NON_UNIQUE);
+#ifdef _WIN32
+	else AllowSetForegroundWindow(ASFW_ANY);
+#endif
 	return -1;
 }
 
@@ -531,8 +547,6 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 			hidden_x = -1;
 		}
 #ifdef _WIN32
-		gtk_window_iconify(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")));
-		while(gtk_events_pending()) gtk_main_iteration();
 		gtk_window_present_with_time(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GDK_CURRENT_TIME);
 #endif
 		if(expressiontext) gtk_widget_grab_focus(expressiontext);
